rm(list=ls(all=TRUE))  # clear all variables
# Programmed by Greg Francis (gfrancis@purdue.edu) December 2013

# Exp. 2 Gino & Mogilner

# define properties of experiment (extent of cheating)
n1 = 35
n2 =35
n3 = 36
n4 = 36
SampleSize = c(n1, n2, n3, n4)
pooleddf = sum(SampleSize)-4


# Personality-money, Personality-time, Intelligence-money, Intelligence-time
Means = c(0.42, 0.49, 1.03, 0.27)
SDs = c(0.81,0.89, 1.85, 0.98)  
pooledVar = sum((SampleSize-1)* SDs* SDs)/pooleddf
SDs = sqrt(pooledVar) + 0* SDs # same for all conditions

numRepeats = 10000
numSuccess = 0

numS1 =0
numS2=0
numS3=0
numS4=0
numS5=0

for(rep in c(1:numRepeats)){

# Draw random samples and run the tests, then compute power for those test from that sample
    PM  <- rnorm(n1, mean=Means[1], sd=SDs[1])
	PT <- rnorm(n2, mean=Means[2], sd=SDs[2])	
	IM <- rnorm(n3, mean=Means[3], sd=SDs[3])
	IT <- rnorm(n4, mean=Means[4], sd=SDs[4])	
	

	# Set up data
	
	TestType<-c()
	Prime <-c()
	Rating <-c()	
		
	for(i in c(1:n1)){
		TestType <- c(TestType, "Personality")
		Prime <- c(Prime, "Money")
		Rating <- c(Rating, PM[i])
	}
	for(i in c(1:n2)){
		TestType <- c(TestType, "Personality")
		Prime <- c(Prime, "Time")
		Rating <- c(Rating, PT[i])
	}
	for(i in c(1:n3)){
		TestType <- c(TestType, "Intelligence")
		Prime <- c(Prime, "Money")
		Rating <- c(Rating, IM[i])
	}	
	for(i in c(1:n4)){
		TestType <- c(TestType, "Intelligence")
		Prime <- c(Prime, "Time")
		Rating <- c(Rating, IT[i])
	}	
	
	dataTwoWay=data.frame(TestType = TestType, Prime = Prime, Rating = Rating)
	
	
	#ANOVA	
	out <- anova(lm(Rating ~ TestType* Prime, dataTwoWay))
	thing<-out$`Pr(>F)`
	interactionP = thing[3]
	thing<-out$`Mean Sq`
	MSE = thing[4]
	thing<-out$`Df`
	dfMSE = thing[4]	
	
	
	# Contrast (for Intelligence test, money vs. time)
	weights <- c(0, 0, -1, 1)
	nweights <- c(weights[1]/sqrt(n1), weights[2]/sqrt(n2), weights[3]/sqrt(n3), weights[4]/sqrt(n4))
	L = weights[1]*mean(PM) + weights[2]*mean(PT) + weights[3]*mean(IM) + weights[4]*mean(IT) 
	t= abs(L)/sqrt(sum(nweights*nweights)*MSE) 		
	contrastP <-  2 * (1 - pt(t, df= dfMSE))
	
	# Contrast (for Personality, money vs. time)  predicted null
	weights <- c(-1, 1, 0, 0)
	L = weights[1]*mean(PM) + weights[2]*mean(PT) + weights[3]*mean(IM) + weights[4]*mean(IT) 
	t= abs(L)/sqrt(sum(nweights*nweights)*MSE) 		
	contrastP2 <-  2 * (1 - pt(t, df= dfMSE))

	# Contrast (Money prime, Intelligence vs. Personality)
	weights <- c(1, 0, -1, 0)
	nweights <- c(weights[1]/sqrt(n1), weights[2]/sqrt(n2), weights[3]/sqrt(n3), weights[4]/sqrt(n4))
	L = weights[1]*mean(PM) + weights[2]*mean(PT) + weights[3]*mean(IM) + weights[4]*mean(IT) 
	t= abs(L)/sqrt(sum(nweights*nweights)*MSE) 		
	contrastP3 <-  2 * (1 - pt(t, df= dfMSE))
	
	# Contrast (Time prime, Intelligence vs. Personality) predicted null
	weights <- c(0, 1, 0, -1)
	nweights <- c(weights[1]/sqrt(n1), weights[2]/sqrt(n2), weights[3]/sqrt(n3), weights[4]/sqrt(n4))
	L = weights[1]*mean(PM) + weights[2]*mean(PT) + weights[3]*mean(IM) + weights[4]*mean(IT) 
	t= abs(L)/sqrt(sum(nweights*nweights)*MSE) 		
	contrastP4 <-  2 * (1 - pt(t, df= dfMSE))	

		# See if all tests rejects as predicted (non-standard criterion for interaction)
			if (interactionP <=0.05 && contrastP<=0.05 && contrastP2>0.05 && contrastP3<=0.05 && contrastP4>0.05)	{
				numSuccess = numSuccess +1
				}
			if(interactionP <=0.05){numS1= numS1+1}
			if(contrastP <=0.05){numS2= numS2+1}
			if(contrastP2 >0.05){numS3= numS3+1}
			if(contrastP3 <=0.05){numS4= numS4+1}
			if(contrastP4 >0.05){numS5= numS5+1}

}

cat("------\n",numSuccess/numRepeats, "\n")

cat("Interaction ", (numS1/numRepeats),"\n")
cat("Contrast 1 ", (numS2/numRepeats),"\n")
cat("Contrast 2 ", (numS3/numRepeats),"\n")
cat("Contrast 3 ", (numS4/numRepeats),"\n")
cat("Contrast 3 ", (numS5/numRepeats),"\n")
