rm(list=ls(all=TRUE))  # clear all variables
# Programmed by Greg Francis (gfrancis@purdue.edu) December 2013

# Exp. 3 Gino & Mogilner

# define properties of experNMMent (extent of cheating)
n1 = 30
n2 = 30
n3 = 30
n4 = 30
SampleSize = c(n1, n2, n3, n4)
pooleddf = sum(SampleSize)-4


# Mirror-money, Mirror-tNMMe, Nomirror-money, Nomirror-tNMMe
Means = c(1.23, 1.14, 4.23, 1.26)
SDs = c(3.02, 2.92, 5.82, 2.62)  
pooledVar = sum((SampleSize-1)* SDs* SDs)/pooleddf
SDs = sqrt(pooledVar) + 0* SDs # same for all condNMTions

numRepeats = 10000
numSuccess = 0

numS1 =0
numS2=0
numS3=0
numS4=0
numS5=0

for(rep in c(1:numRepeats)){

# Draw random samples and run the tests, then compute power for those test from that sample
    MM  <- rnorm(n1, mean=Means[1], sd=SDs[1])
	MT <- rnorm(n2, mean=Means[2], sd=SDs[2])	
	NMM <- rnorm(n3, mean=Means[3], sd=SDs[3])
	NMT <- rnorm(n4, mean=Means[4], sd=SDs[4])	
	

	# Set up data
	
	Condition<-c()
	Prime <-c()
	Rating <-c()	
		
	for(i in c(1:n1)){
		Condition <- c(Condition, "Mirror")
		Prime <- c(Prime, "Money")
		Rating <- c(Rating, MM[i])
	}
	for(i in c(1:n2)){
		Condition <- c(Condition, "Mirror")
		Prime <- c(Prime, "Time")
		Rating <- c(Rating, MT[i])
	}
	for(i in c(1:n3)){
		Condition <- c(Condition, "NoMirror")
		Prime <- c(Prime, "Money")
		Rating <- c(Rating, NMM[i])
	}	
	for(i in c(1:n4)){
		Condition <- c(Condition, "NoMirror")
		Prime <- c(Prime, "Time")
		Rating <- c(Rating, NMT[i])
	}	
	
	dataTwoWay=data.frame(Condition = Condition, Prime = Prime, Rating = Rating)
	
	
	#ANOVA	
	out <- anova(lm(Rating ~ Condition* Prime, dataTwoWay))
	thing<-out$`Pr(>F)`
	interactionP = thing[3]
	thing<-out$`Mean Sq`
	MSE = thing[4]
	thing<-out$`Df`
	dfMSE = thing[4]	
	
	
	# Contrast (Main effect for prime condition)
	weights <- c(-1, 1, -1, 1)
	nweights <- c(weights[1]/sqrt(n1), weights[2]/sqrt(n2), weights[3]/sqrt(n3), weights[4]/sqrt(n4))
	L = weights[1]*mean(MM) + weights[2]*mean(MT) + weights[3]*mean(NMM) + weights[4]*mean(NMT) 
	t= abs(L)/sqrt(sum(nweights*nweights)*MSE) 		
	contrastP1 <-  2 * (1 - pt(t, df= dfMSE))
	
	# Contrast (main effect for mirror condition)
	weights <- c(1, 1, -1, -1)
	L = weights[1]*mean(MM) + weights[2]*mean(MT) + weights[3]*mean(NMM) + weights[4]*mean(NMT) 
	t= abs(L)/sqrt(sum(nweights*nweights)*MSE) 		
	contrastP2 <-  2 * (1 - pt(t, df= dfMSE))

	# Contrast (No mirror, money vs.prime)
	weights <- c(0, 0, -1, 1)
	nweights <- c(weights[1]/sqrt(n1), weights[2]/sqrt(n2), weights[3]/sqrt(n3), weights[4]/sqrt(n4))
	L = weights[1]*mean(MM) + weights[2]*mean(MT) + weights[3]*mean(NMM) + weights[4]*mean(NMT) 
	t= abs(L)/sqrt(sum(nweights*nweights)*MSE) 		
	contrastP3 <-  2 * (1 - pt(t, df= dfMSE))
	
	# Contrast (Mirror, money vs.prime) predicted null
	weights <- c(-1, 1, 0, 0)
	nweights <- c(weights[1]/sqrt(n1), weights[2]/sqrt(n2), weights[3]/sqrt(n3), weights[4]/sqrt(n4))
	L = weights[1]*mean(MM) + weights[2]*mean(MT) + weights[3]*mean(NMM) + weights[4]*mean(NMT) 
	t= abs(L)/sqrt(sum(nweights*nweights)*MSE) 		
	contrastP4 <-  2 * (1 - pt(t, df= dfMSE))	

		# See if all tests rejects as predicted (non-standard crNMTerion for interaction)
			if (interactionP <=0.05 && contrastP1<=0.05 && contrastP2<=0.05 && contrastP3<=0.05 && contrastP4>0.05)	{
				numSuccess = numSuccess +1
				}
			if(interactionP <=0.05){numS1= numS1+1}
			if(contrastP1 <=0.05){numS2= numS2+1}
			if(contrastP2 <=0.05){numS3= numS3+1}
			if(contrastP3 <=0.05){numS4= numS4+1}
			if(contrastP4 >0.05){numS5= numS5+1}

}

cat("------\n",numSuccess/numRepeats, "\n")

cat("Interaction ", (numS1/numRepeats),"\n")
cat("Contrast 1 ", (numS2/numRepeats),"\n")
cat("Contrast2 ", (numS3/numRepeats),"\n")
cat("Contrast3 ", (numS4/numRepeats),"\n")
cat("Contrast4 ", (numS5/numRepeats),"\n")
